@@ -35,3 +35,19 @@ class AWSHub(BaseHub):
             resp = await client.get(url)
 
         await cls.put_file(key, resp.content, bucket=bucket)
+
+    @classmethod
+    async def exists_file(cls, filepath: str, bucket = None):
+        try:
+            session = get_session()
+            async with session.create_client(
+                's3', region_name = ConfigHub.get('aws.region', 'us-east-1'),
+                aws_secret_access_key = ConfigHub.get('aws.secret_key'),
+                aws_access_key_id = ConfigHub.get('aws.access_key'),
+                endpoint_url = ConfigHub.get('aws.endpoint')
+            ) as s3:
+                await s3.get_object_acl(Bucket=bucket if bucket else ConfigHub.get('aws.s3.bucket'), Key=filepath)
+
+                return True
+        except:
+            return False
